pub struct ExecTrace {
pub action: Action,
pub valid: bool,
}Expand description
Trace localized in vector of traces produced by a single transaction.
Parent and children indexes refer to positions in this vector.
Fields
action: ActionType of action performed by a transaction.
valid: boolImplementations